@@ -16,21 +16,17 @@ Bio::Phylo::CIPRES - Reusable components for CIPRES REST API access
 
 =head1 SYNOPSIS
 
- my %result = Bio::Phylo::CIPRES->new( 
+ my $cipres = Bio::Phylo::CIPRES->new( 
  	'infile'    => 'infile.fasta',                 # input data file
  	'tool'      => 'MAFFT_XSEDE',                  # tool to run
  	'param'     => { 'vparam.runtime_' => 7.5 },   # extra parameters, e.g. max runtime
  	'outfile'   => { 'output.mafft' => 'out.fa' }, # name of output data to fetch
  	'yml'       => 'config.yml',	               # client credentials
- )->run;
+ );
  
- while( my ( $name, $data ) = each %result ) {
+ my $url = $cipres->run;
  
-    # write data to output file
- 	my $outfile = "${name}.fasta";
- 	open my $fh, '>', $outfile or die $!;
- 	print $fh $data;
- } 
+ $cipres->clean_job( $url );
 
 =head1 DESCRIPTION
 
@@ -75,7 +71,7 @@ interfaces.
 
 # global constants
 our $AUTOLOAD;
-use version; our $VERSION = qv("v0.2.0");
+use version; our $VERSION = qv("v0.2.1");
 my $REALM = "Cipres Authentication";
 my $PORT  = 443;
 
@@ -358,6 +354,30 @@ sub DESTROY {
 Also consult the documentation for L<cipresrun>, which shows the usage of this module
 from the command line.
 
+=head1 LICENSE
+
+MIT License
+
+Copyright (c) 2020 Naturalis Biodiversity Center
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
+
 =cut
 
 1;
